#
# spec file for package e16
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define enable_sound       0
%define enable_hints_gnome 0
%define enable_zoom        1
%define enable_xrandr      1
%define enable_composite   1
%define enable_pango       1
Name:           e16
Version:        1.0.24
Release:        1.10
Summary:        A Window Manager for the X Window System
License:        GPL-2.0-or-later AND MIT-advertising
Group:          System/GUI/Other
URL:            https://www.enlightenment.org
Source:         e16-%{version}.tar.xz
Patch0:         fix-compile-gtk.patch
BuildRequires:  fdupes
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(harfbuzz) >= 0.9.7
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(imlib2) >= 1.2.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
Requires:       imlib2-loaders
#conflict with the old enlightenment package
Conflicts:      enlightenment >= 1.0.0
Provides:       windowmanager
Obsoletes:      enlight < %{version}
Provides:       enlight = %{version}
# don't use provides as that will cause issues with the new enlightenment (e18) package
Obsoletes:      enlightenment >= 1.0.0
%if %{enable_sound}
BuildRequires:  pkgconfig(libpulse)
%endif
%if %{enable_pango}
BuildRequires:  pkgconfig(pango)
%endif

%description
Enlightenment is a window manager for the X Window System that is
extensible and configurable looking. It is one of the more
graphically intense window managers.

Enlightenment goes beyond managing windows by providing a graphical
shell from which to work. It allows the user to define their own
policy down to every last detail.

%prep
%setup -q
%autopatch -p1

%build
%if 0%{?sles_version} != 10
autoreconf -fi
%endif
%configure \
        --disable-roothacklib \
%if %{enable_sound}
	--enable-sound \
%else
	--disable-sound \
%endif
%if %{enable_hints_gnome}
	--enable-hints-gnome \
%else
	--disable-hints-gnome \
%endif
%if %{enable_zoom}
	--enable-zoom \
%else
	--disable-zoom \
%endif
%if %{enable_xrandr}
	--enable-xrandr \
%else
	--disable-xrandr \
%endif
%if %{enable_composite}
	--enable-composite \
%else
	--disable-composite \
%endif
%if %{enable_pango}
	--enable-pango
%else
	--disable-pango
%endif
%make_build

%install
make DESTDIR=%{buildroot} \
     localedir=%{_datadir}/locale \
     gnulocaledir=%{_datadir}/locale \
     install
find %{buildroot}%{_datadir}/e16/themes -type d | xargs chmod 755
find %{buildroot}%{_datadir}/e16/themes -type f | xargs chmod 644
rm %{buildroot}%{_datadir}/applications/e16.desktop
rm %{buildroot}%{_datadir}/xsessions/e16-{gnome2,gnome3,kde}-session.desktop
rm -rf %{buildroot}%{_datadir}/gnome-session
rm -rf %{buildroot}%{_datadir}/e16/fonts
%if 0%{?suse_version} >= 1100
%fdupes -s %{buildroot}%{_datadir}/e16/themes/winter
%endif
%find_lang e16

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files -f e16.lang
%doc AUTHORS ChangeLog TODO
%license COPYING
%{_bindir}/*
%{_bindir}/starte16
%{_libdir}/e16/
%{_datadir}/e16
%{_datadir}/doc/e16
%{_mandir}/man1/*
%{_datadir}/xsessions/*

%changelog
* Thu Feb 24 2022 Simon Lees <simonf.lees@suse.com>
- Update to 1.0.24
  * Pagers: Remember zoom setting when changed by pager menu
  * Systray: Change default icon size to 32
  * Support _NET_WM_STATE_FOCUSED
  * Focus: Fix focus on new clients requesting max size
  * Fix bad memory access during shutdown
  * FX (waves/ripples): Make it work in compositing mode
  * Sound: Enable having multiple engines and changing it at runtime
  * Translation updates: fr, da
- Refreshed fix-compile-gtk.patch
* Mon Jul  5 2021 Simon Lees <sflees@suse.de>
- Update to 1.0.23
  * Add option to allow only the primary mouse button to raise windows
  * Use poll() for event handling by default
  * Allow users to override fonts via ~/.e16/fonts/
  * bindings: Add 'W' as alias for modifier 4
  * Enable sounds in combined configuration dialog
  * Optionally play sounds using audio player
  * Avoid potential crash when attempting to enable sound
  * Add alsa-lib sound backend
  * Various bugfixes
  * Add sndio sound back end for OpenBSD
  * Menu generation speedups
  * Translation updates: fr
- Refreshed fix-compile-gtk.patch
- Run spec cleaner
* Thu Jan  2 2020 Simon Lees <sflees@suse.de>
- Add sndio sound back end for OpenBSD
- Menu generation speedups
* Thu Sep  5 2019 Simon Lees <sflees@suse.de>
- Update to 16.0.20
  * Theming macro updates (Don Harrop)
  * Warning fixes for gcc 9
  * Fix transient placement involving desk/area change
  * GSOD: Fix restart after choosing Restart on e.g. segv
  * GSOD: Better keyboard grab
  * Don't do double-clicks on scroll wheel events
  * Correct refresh when switching away from background "None"
  * Restore background to last set if quitting background selector
  * Fix memory leak in pulseaudio sound loader
  * Fix potential segv in pulseaudio sound handler
  * Fix compositing glitches with tiled backgrounds
  * Make config dialog edge flip mode changes take effect immediately
  * Add gobject-2.0 dependency in case pango doesn't include it
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and filler wording from description.
* Wed May 29 2019 Simon Lees <sflees@suse.de>
- Update to 16.0.19
  * Fix focus after slide-in
  * Fix issue with initially shaded windows in certain cases
  * Add new macros for theming in 'definitions'
  * Update the restart cursor which looked a bit dated
  * Do proper rendering of transparent icons in menus
  * Fix magnifier pixel value display
  * Remove long disabled pseudotransparency support
  * Fix focus-if-group-focused cases
  * (warning) fixes for gcc8
  * (warning) fixes for recent support package versions
  * autotool updates
- use %%license macro
- add fix-compile-gtk.patch as a hack for pango dropping gobj
  flags
* Wed Sep 27 2017 dimstar@opensuse.org
- Fixup sound dependencies: we pass --enable-sound to configure,
  which, according to configure, implies 'pulseaudio' (unless
  specified as --enable-sound=esound).
  + Drop esound-devel BuildRequires: not needed, since we never
    passed --enable-sound=esound to configure.
  + Drop pkgconfig(alas) BuildRequires: no needed, since e16 has no
    alsa support.
  + Add pkgconfig(libpulse) BuildRequires: Enable the implied sound
    module for 16.
- Toggle with_sound to 0, until somebody actually fixes the build
  with PulseAudio (note: this is defacto the same as we had before
  as the dependencies were simply not in place and configure
  silently switched off --enable-sound).
* Fri Jun 16 2017 simonf.lees@suse.com
- Fix license should be MIT-advertising and GPL-2.0+
* Wed May 10 2017 sflees@suse.de
- Update to 1.0.18 - warnings / autotools fixes
* Fri Oct  9 2015 sleep_walker@opensuse.org
- add cairo as build requirement
- add harfbuzz as build requirement
* Thu Aug  6 2015 simon@simotek.net
- update to 1.0.17 - bug fixes
* Sat Oct 18 2014 crrodriguez@opensuse.org
- Run spec-cleaner
- Discontinue use of metapackage xorg-x11-devel replacing it
  by specific pkgconfig() requires.
- Enable verbose build.
* Tue Apr  8 2014 simon@simotek.net
- Update to 1.0.14 - Release Notes Below
    There are apparently still a couple of e16 users out there, so
    e16-1.0.14 is available for download:
    http://sourceforge.net/projects/enlightenment/files/
    There are no major changes since e16-1.0.13.
    Mostly a couple of minor bug fixes and some internal reworkings.
* Tue Jan 21 2014 cfarrell@suse.com
- license update: MIT and GPL-2.0+
  SPDX
* Fri Jan 17 2014 simon@simotek.net
- License is really MIT and GPL2+ (epp)
* Tue Jan 14 2014 simon@simotek.net
- Recreated e16 package in X11:Enlightenment:E16:Factory from
  enlightenment package in X11:WindowMangers
* Fri Sep 13 2013 jmatejek@suse.com
- update to 1.0.13
  * translation updates
  * minor cleanup/bugfixes
  * many warnings cleared
- restored xsession menu entry
- simplified spec filelist
* Wed Aug  7 2013 ro@suse.de
- fix filelist to fix build on factory: recent rpm allows only
  directories with a trailing "/", not regular files
* Wed Dec  5 2012 sleep_walker@suse.cz
- use fdupes only for SUSE > 11
- disable autoreconf for SLE10
* Tue Dec  4 2012 sleep_walker@suse.cz
- remove duplicates with fdupes
- don't explicitly require imlib2
- fix provides/obsoletes
* Fri Nov 30 2012 sleep_walker@suse.cz
- bump to 1.0.11
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Aug  6 2009 matejcik@suse.cz
- update to 1.0.0
  * mostly bugfix release
  * should've been 0.16.8.18, but upstream decided that the package
  is "done"
* Fri Sep 12 2008 matejcik@suse.cz
- update to 0.16.8.14
  * mostly bugfix release
* Thu Apr 17 2008 matejcik@suse.cz
- update to 0.16.8.12
  * support for pango fonts
  * better menu configuration
  * bugfixes
- requires imlib2-loaders, to offset imlib2 packaging bug on 10.3
- removed nonfunctional e16-kde and e16-gnome sessions
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang errors
- use RPM_OPT_FLAGS
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Wed Feb 28 2007 jmatejek@suse.cz
- removed /usr/share/xsessions directory from filelist
  (bug #248719)
* Fri Feb 16 2007 matejcik@suse.cz
- fixed wrong ${prefix} expansion that that was effectively disabling
  system-wide themes and making enlightenment unusable
  in default configuration
  (bug #246294)
* Thu Dec 14 2006 ro@suse.de
- move from usr/X11R6 to usr
* Tue Aug  8 2006 pnemec@suse.cz
- fix spec file to build with new gettext 0.15
* Fri Jul 14 2006 pnemec@suse.cz
- updated to 0.16.8.1
- package enlightenment was transfered to BuildService
- cleared spec file
- removed nearly all patches
- added susemenu.diff
- themes subpackage is removed completly
* Tue Jul  4 2006 pnemec@suse.cz
- updated to 0.16.7.2
- cleared spec file
- themes are not part of source file anymore
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 21 2005 ro@suse.de
- added locale dirs to filelist
* Thu Oct  6 2005 pnemec@suse.cz
- fixed uninitialized variables
* Thu Apr 14 2005 sbrabec@suse.cz
- Added audiofile-devel to neededforbuild.
* Thu Feb 10 2005 adrian@suse.de
- install session desktop file
* Sat Mar 20 2004 mmj@suse.de
- Compile with -fno-strict-aliasing
- Remove rogue .xvpics dirs
- Use %%_lib
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Nov  7 2003 ltinkl@suse.cz
- update to latest stable version 0.16.6
* Mon Jun 16 2003 kukuk@suse.de
- Use %%find_lang macro
* Mon Mar  3 2003 pmladek@suse.cz
- fixed themes to use iso8859-* instead of iso8859-1 in config files
  to work also with East European languages, many thanks to Stanislav
  Brabec <sbrabec@suse.cz> for hint [#20658]
* Tue Nov 12 2002 pmladek@suse.cz
- used x-devel-packages and XFree86 in neededforbuild to conform to
  the new naming scheme of the XFree86 stuff
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Sun Jun 23 2002 ro@suse.de
- fix directories permissions
* Wed Feb 20 2002 postadal@suse.cz
- fixed eesh to work on the first attempt
- fixed to read also menu from KDE 3
* Tue Feb 12 2002 pmladek@suse.cz
- used %%defattr(-,root,root)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Mon Nov  5 2001 pmladek@suse.cz
- added support for SuSE menu generated by susewm
- fixed test on KDE, GNOME menu presence
- added test on gnome-config presence
* Tue Oct  2 2001 pmladek@suse.cz
- fixed menu from KDE 2
- cleaned up spec file
- removed unneeded patch for configure
* Mon Feb 19 2001 ro@suse.de
- changed neededforbuild <libghtt> to <libghttp>
- changed neededforbuild <libghtt-devel> to <libghttp-devel>
* Fri Jan 26 2001 violiet@suse.de
- Added korean-pack package support for Korean.
- Install international message.
* Fri Dec 29 2000 egger@suse.de
- Fixed bug 5049 by including esound-devel.
- Use SuSE optimisation flags.
- General specfile cleanup.
* Sun Nov  5 2000 ro@suse.de
- fixed neededforbuild
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Sun Oct  1 2000 egger@suse.de
- Cleaned up specfile.
- Removed unnecessary ImageMagick dependency.
- Updated to version 0.16.5.
* Mon May 15 2000 egger@suse.de
- Updated to version 0.16.4.
* Sat Mar  4 2000 ro@suse.de
- try to avoid specfile bug
* Tue Feb 29 2000 grimmer@suse.de
- Update to 0.16.3 (#2026)
- reworked spec file (BuildRoot, group tag, version macro, URL)
- now uses sane path names (--enable-fsstd)
- enabled sound
- removed obsolete patches and profile script
* Fri Jan 21 2000 ro@suse.de
- freetype is in /usr/include/freetype now
* Tue Oct 12 1999 grimmer@suse.de
- Updated to 0.16.0
- Specfile cleanups, created more symlinks for binaries
- Added Authors to PAC file and rewrote package descriptions
* Mon Sep 20 1999 ro@suse.de
- added Provides windowmanager
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Thu Jul  1 1999 uli@suse.de
- changed refs to libgif to libungif
* Tue May  4 1999 mb@suse.de
- updated to version 0.15.5 using autospec
  Fri Feb 19 16:42:56 MET 1999
- updated to version 0.14
* Thu Oct 29 1998 ro@suse.de
- updated neededforbuild
* Sat Jul 18 1998 mb@suse.de
- this is the SNAP release of the enlightenment window manager
- version 0.14
- the manager has been completely redesigned
* Wed Nov  5 1997 kgw@suse.de
  first SuSE version, ready for autobuild.
